@@ -55,7 +55,7 @@ $helper->mk_component ( $appname, 'controller', 'InstantCRUD', 'InstantCRUD',
 );
 
 my @appdirs = split /::/, $appname;
-my $rootcontrl = File::Spec->catdir ( $appdir, 'lib',  @appdirs, 'Controller', 'Root.pm') ;
+my $rootcontrl = File::Spec->catdir ( $appdir, 'lib',  @appdirs, ($short ? 'C' : 'Controller'), 'Root.pm') ;
 
 my $rootcontrlcont = read_file($rootcontrl);
 my $default = q{
@@ -64,10 +64,18 @@ sub default : Private {
     $c->response->status(404);
     $c->response->body("404 Not Found");
 };
+sub index : Private{
+    my ( $self, $c ) = @_;
+    my @additional_paths = ( File::Spec->catdir ( $c->config->{root}, "InstantCRUD" ) );
+    $c->stash->{additional_template_paths} = \@additional_paths;
+    $c->stash->{template} = 'home.tt';
+}
 };
 
-$rootcontrlcont =~ s{sub default : Private }
-                 {$default . "\n\nsub index : Private" }e;
+$rootcontrlcont =~ s/sub default : Private [^}]*\}/$default/es;
+
+#$rootcontrlcont =~ s{use base .*}{use base 'Catalyst::Example::Controller::InstantCRUD';};
+
 write_file($rootcontrl, $rootcontrlcont) or die "Cannot write main application file";
 
 my @appdirs = split /::/, $appname;
@@ -87,9 +95,7 @@ View::TT:
 
 my $configname = Catalyst::Utils::appprefix ( $appname ) . '.yml';
 my $appconfig = File::Spec->catdir ( $appdir, $configname ) ;
-open CONFIG, '>>', $appconfig;
-print CONFIG $config;
-close CONFIG;
+write_file( $appconfig, {append => 1}, $config) or die "Cannot uppend to $appconfig: $!";
 
 my $loader = DBIx::Class::Loader->new(
     dsn       => $dsn,
@@ -99,7 +105,7 @@ my $loader = DBIx::Class::Loader->new(
 );
 my $sdir = File::Spec->catdir ( $appdir, 'lib', 'DBSchema' );
 mkdir $sdir or die "Cannot create directory $sdir: $!";
-my @models;
+my %models;
 for my $c ( $loader->classes ) {
     my $table = $c->table;
     my @columns = $c->columns;
@@ -121,12 +127,11 @@ __PACKAGE__->set_primary_key('$primary_key');
 };
     $c =~ /\W*(\w+)$/;
     my $modelfile = File::Spec->catdir ( $appdir, 'lib', 'DBSchema', "$1.pm" );
-    push @models, $1;
-    open MODEL, '>', $modelfile;
-    print MODEL $model;
-    close MODEL;
+    $models{$table} = $1;
+    write_file( $modelfile, $model) or die "Cannot write to $modelfile: $!";
 }
 
+my @models = values %models;
 my $schema = qq{
 package DBSchema;
 
@@ -136,13 +141,59 @@ __PACKAGE__->load_classes(qw/@models/);
 };
 
 my $schemafile =  File::Spec->catdir ( $appdir, 'lib', 'DBSchema.pm');
-open SCHEMA, '>', $schemafile or die "Cannot write to $schemafile: $!";
-print SCHEMA $schema;
-close SCHEMA;
+write_file( $schemafile, $schema ) or die "Cannot write to $schemafile: $!";
 
 my $tfile =  File::Spec->catdir ( $appdir, 't', 'controller_InstantCRUD.t' );
 unlink $tfile or die "Cannot remove $tfile - the wrong test file: $!";
 
+my $table_menu = '| <a href="[% base %]">Home</a> |';
+for my $table (keys %models){
+    $table_menu .= ' <a href="[% base %]' . lc $models{$table} . "\">$table</a> |";
+}
+my $table_menu_file = File::Spec->catdir ( $appdir, 'root', 'InstantCRUD', 'table_menu' );
+write_file( $table_menu_file, $table_menu ) or die "Cannot write to $table_menu_file: $!";
+
+my $home = q{
+This is an application generated by  
+<a href="http://search.cpan.org/~zby/Catalyst-Example-InstantCRUD-v0.0.9/lib/Catalyst/Example/InstantCRUD.pm">Catalyst::Example::InstantCRUD</a>
+- a generator of simple database applications for the 
+<a href="http://catalyst.perl.org">Catalyst</a> framework.
+See also 
+<a href="http://cpansearch.perl.org/dist/Catalyst/lib/Catalyst/Manual/Intro.pod">Catalyst::Manual::Intro</a>
+and
+<a href="http://cpansearch.perl.org/dist/Catalyst/lib/Catalyst/Manual/Tutorial.pod">Catalyst::Manual::Tutorial</a>
+};
+
+my $home_file = File::Spec->catdir ( $appdir, 'root', 'InstantCRUD', 'home.tt' );
+write_file( $home_file, $home) or die "Cannot write to $home_file: $!";
+
+my $wrapper = q{
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
+    "http://www.w3.org/TR/xhtml1/DTD/xhtml11.dtd">
+<html xmlns="http://www.w3.org/1999/xhtml">
+    <head>
+        <title>
+            [% appname %]
+        </title>
+        <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
+        <link title="Maypole" href="[%base%]static/pagingandsort.css" type="text
+/css" rel="stylesheet"/>
+    </head>
+    <body>
+        <div class="table_menu">
+            [% PROCESS table_menu %]
+        </div>
+        <div class="content">
+            [% content %]
+        </div>
+    </body>
+</html>
+};
+
+my $wrapper_file = File::Spec->catdir ( $appdir, 'root', 'InstantCRUD', 'wrapper.tt' );
+write_file( $wrapper_file, $wrapper) or die "Cannot write to $wrapper_file: $!";
+
+
 1;
 
 __END__
@@ -278,7 +329,7 @@ L<Catalyst::Manual>, L<Catalyst::Manual::Intro>
 Sebastian Riedel, C<sri@oook.de>,
 Andrew Ford, C<A.Ford@ford-mason.co.uk>
 Zbigniew Lukasiak, C<zz bb yy@gmail.com> - modifications
-
+Jonathan Manning
 
 =head1 COPYRIGHT
 
